From 79764e9e4debea51884177dd0a4936aa82c2457a Mon Sep 17 00:00:00 2001
From: tkellner <tkellner@8a26b1a7-26f0-462f-b9ef-d0e30c41f5a4>
Date: Wed, 10 Aug 2011 08:02:15 +0000
Subject: Rename (rexep -> regexp)

git-svn-id: https://joinup.ec.europa.eu/svn/mocca/trunk@950 8a26b1a7-26f0-462f-b9ef-d0e30c41f5a4
---
 smcc/src/main/java/at/gv/egiz/smcc/PinInfo.java | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

(limited to 'smcc/src')

diff --git a/smcc/src/main/java/at/gv/egiz/smcc/PinInfo.java b/smcc/src/main/java/at/gv/egiz/smcc/PinInfo.java
index 107cd18e..51a7a5ef 100644
--- a/smcc/src/main/java/at/gv/egiz/smcc/PinInfo.java
+++ b/smcc/src/main/java/at/gv/egiz/smcc/PinInfo.java
@@ -59,7 +59,7 @@ public class PinInfo {
   /**
    * The regular expression pattern of a single PIN digit or character.
    */
-  protected final String rexepPattern;
+  protected final String regexpPattern;
   
   /**
    * The name of the corresponding resource bundle.
@@ -101,18 +101,18 @@ public class PinInfo {
    * 
    * @param minLenght the minimum length of the PIN
    * @param maxLength the maximum length of the PIN, or -1 if there is no maximum length
    * @param rexepPattern the regular expression pattern of a single PIN digit or character
    * @param resourceBundleName the name of a ResourceBundle for this PIN
    * @param resourceKey the key to look up the (localized) name of this PIN
    * @param kid the key id of the PIN
    * @param contextAID the AID the KID is valid in
    */
-  public PinInfo(int minLenght, int maxLength, String rexepPattern,
+  public PinInfo(int minLenght, int maxLength, String regexpPattern,
       String resourceBundleName, String resourceKey, byte kid, byte[] contextAID, int maxRetries) {
 
     this.minLength = minLenght;
     this.maxLength = maxLength;
-    this.rexepPattern = rexepPattern;
+    this.regexpPattern = regexpPattern;
     this.resourceBundleName = resourceBundleName;
     this.nameKey = resourceKey + ".name";
     this.kid = kid;
@@ -213,8 +213,8 @@ public class PinInfo {
   /**
    * @return the regular expression pattern of one single digit or character
    */
-  public String getRexepPattern() {
-    return rexepPattern;
+  public String getRegexpPattern() {
+    return regexpPattern;
   }
 
   /**
@@ -101,18 +101,18 @@ public class PinInfo {
    * @param minLenght the minimum length of the PIN
    * @param maxLength the maximum length of the PIN, or -1 if there is no maximum length
-   * @param rexepPattern the regular expression pattern of a single PIN digit or character
+   * @param regexpPattern the regular expression pattern of a single PIN digit or character
    * @param resourceBundleName the name of a ResourceBundle for this PIN
    * @param resourceKey the key to look up the (localized) name of this PIN
-- 
cgit v1.2.3